/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import type { IPluginId } from '@/service/modules/ui-plugins/types'
import type { TableColumns } from 'naive-ui/es/data-table/src/interface'
import type {
  IMeta,
  IJsonItem,
  IFormItem,
  IFormRules
} from '@/components/form/types'

interface IRecord {
  alertPluginName?: string
  createTime?: string
  id: number
  instanceName: string
  pluginDefineId: number
  pluginInstanceParams?: string
  updateTime?: string
}

interface IPlugin {
  id: number
  pluginName: string
  pluginParams?: string
  pluginType?: string
  createTime?: string
  updateTime?: string
}

export {
  IPluginId,
  IRecord,
  IPlugin,
  IJsonItem,
  IMeta,
  IFormItem,
  TableColumns,
  IFormRules
}
